@echo off
cls
REM **********************************************************************
REM Description	: compiling batch-file for 64-bit versions
REM Author		: Mucci
REM Date		: 2020-09-01
REM
REM Changes		: 1.0  first release
REM             : 1.01 Read the sytem variable for amount of cpu for the compile option "-j"
REM                    -Due to a compile problem with HBMAME I have set the compile option to "-j5"
REM                    Download only source for an emulator that we want to compile
REM               1.1  Added choice to compile older builds
REM ***********************************************************************

REM This script is used only for the MAMEdev tools
REM Place this script and Notepad2.exe to your \src\ folder
REM Start always win32env.bat first (Environment) and after that "compile-64bitBuilds.cmd"
REM ------------------------------------------------------------------------------------------------------

REM Set the default values for some settings
REM CPU Core -> amount of cpu and add 1
REM Example: dual-core or quad-core processor -> use the option -j3 or -j5
REM set autodetect according to the  system variable
REM set /a THREADS=%NUMBER_OF_PROCESSORS% + 1
REM set Compilecpu=j%THREADS%
REM Or set it manually, as I had problem in the past with a high value I have set it to this low value (compiles takes much longer)
set Compilecpu=j5
REM set default values for pause: on or off (default=on, on/off)
set batchpause=on
REM set default values for doing a clean before compiling: on or off (default=off, on/off)
set cleanmode=off
REM Set default values for versions to compile (Default=on, on/off)
set C_MAME=on
set C_MESS=on
set C_MAMEARCADE=on
set C_ARCADE=on
set C_MAMEui=on
set C_MESSui=on
set C_HBMAME=on

REM ------------------------------------------------------------------------------------------------------
REM Displaying a start information
ECHO    --------------------------------------------------
ECHO      Compiling batch-file starting
ECHO      for
ECHO      MAME/MESS/MAMEARCADE/ARCADE/MAMEui/MESSui/HBAME
ECHO    --------------------------------------------------
ECHO         (c) 2020 mameguide.info
ECHO.
ECHO.
REM jump to the chosen part
CHOICE /C yn /N /M "Do you want to compile the latest build? (y/n)"
ECHO.
IF ERRORLEVEL 2 GOTO JP-Compile_choice
IF ERRORLEVEL 1 GOTO JP-Compile_latest
:JP-Compile_choice
ECHO.
ECHO -----------------------------------------------------------------------------------------
ECHO  Be sure that you enter a valid version that can be compiled, otherwise the script fails
ECHO -----------------------------------------------------------------------------------------
ECHO.
SET /P enterversion=Please enter the version number you want to compile (example: 224): 
set MAME_VERSION=mame0%enterversion%
set ARCADE_VERSION=tag%enterversion%
set MAMEui_VERSION=tag%enterversion%
set MESSui_VERSION=tag%enterversion%
set HBMAME_VERSION=tag%enterversion%
ECHO.
goto JP-MENU

:JP-Compile_latest
ECHO    --------------------------------------------------
ECHO.     retrieving version numbers remote
ECHO    --------------------------------------------------
REM Checking versions of MAME/MESS/MAMEARCADE/ARCADE/MAMEui/MESSui/HBAME
git ls-remote --tags https://github.com/mamedev/mame.git > mame_tags.txt
for /f "delims==" %%a in (mame_tags.txt) do set lastline=%%a
set MAME_VERSION=%lastline:~51,8%
echo      MAME:   %MAME_VERSION%

git ls-remote --tags https://github.com/Robbbert/store1.git > arcade_tags.txt
findstr refs/tags/tag arcade_tags.txt > arcade_tags2.txt
for /f "delims==" %%a in (arcade_tags2.txt) do set lastline=%%a
set ARCADE_VERSION=%lastline:~51,6%
echo      ARCADE: %ARCADE_VERSION%

git ls-remote --tags https://github.com/Robbbert/mameui.git > mameui_tags.txt
for /f "delims==" %%a in (mameui_tags.txt) do set lastline=%%a
set MAMEui_VERSION=%lastline:~51,6%
echo      MAMEui: %MAMEui_VERSION%

git ls-remote --tags https://github.com/Robbbert/messui.git > messui_tags.txt
for /f "delims==" %%a in (messui_tags.txt) do set lastline=%%a
set MESSui_VERSION=%lastline:~51,6%
echo      MESSui: %MESSui_VERSION%

git ls-remote --tags https://github.com/Robbbert/hbmame.git > hbmame_tags.txt
for /f "delims==" %%a in (hbmame_tags.txt) do set lastline=%%a
set HBMAME_VERSION=%lastline:~51,6%
echo      HBMAME: %HBMAME_VERSION%
ECHO    ----------------------------------------------------------------------
ECHO      Check the versions numbers/tag. if they are strange exit the script
ECHO    ----------------------------------------------------------------------
pause

REM Main menu
:JP-MENU
cls
ECHO    ---------------------------------------------------
ECHO      Compiling 64bit versions V1.1
ECHO                 for
ECHO      MAME/MESS/MAMEARCADE/ARCADE/MAMEui/MESSui/HBAME
ECHO    ---------------------------------------------------
ECHO            (c) 2020 mameguide.info
ECHO    ---------------------------------------------------
ECHO.
ECHO    [1] = MAME        %MAME_VERSION%      (%C_MAME%)
ECHO    [2] = MESS        %MAME_VERSION%      (%C_MESS%)
ECHO    [3] = MAMEARCADE  %MAME_VERSION%      (%C_MAMEARCADE%) 
ECHO    [4] = ARCADE      %ARCADE_VERSION%        (%C_ARCADE%)
ECHO    [5] = MAMEui      %MAMEui_VERSION%        (%C_MAMEui%)
ECHO    [6] = MESSui      %MESSui_VERSION%        (%C_MESSui%)
ECHO    [7] = HBMAME      %HBMAME_VERSION%        (%C_HBMAME%)
ECHO    ---------------------------------------
ECHO    [C] = Compile
ECHO    ---------------------------------------
ECHO    (X) = Before compiling do a clean: %cleanmode%
ECHO    (P) = Batch Pause Mode           : %batchpause%
ECHO    ---------------------------------------
ECHO    [E] = Exit
ECHO    ---------------------------------------
ECHO.
ECHO    ---------------------------------------
ECHO    Note: When you having problems with 
ECHO          compiling and tools are not -/+ 
ECHO          generated - enable "clean" !!!!
ECHO    ---------------------------------------
ECHO.
REM jump to the chosen part
CHOICE /C 1234567CXPE /N /M "Command: "
IF ERRORLEVEL 11 GOTO JP-EXIT
IF ERRORLEVEL 10 GOTO JP-PauseMode1
IF ERRORLEVEL 9 GOTO JP-CleanMode1
IF ERRORLEVEL 8 GOTO JP-Compiling1
IF ERRORLEVEL 7 GOTO JP-KEY_HBMAME1
IF ERRORLEVEL 6 GOTO JP-KEY_MESSui1
IF ERRORLEVEL 5 GOTO JP-KEY_MAMEui1
IF ERRORLEVEL 4 GOTO JP-KEY_ARCADE1
IF ERRORLEVEL 3 GOTO JP-KEY_MAMEARCADE1
IF ERRORLEVEL 2 GOTO JP-KEY_MESS1
IF ERRORLEVEL 1 GOTO JP-KEY_MAME1

REM Enable/Disable MAME
:JP-KEY_MAME1
if [%C_MAME%] EQU [on] goto JP-KEY_MAME2
if [%C_MAME%] EQU [off] goto JP-KEY_MAME3
:JP-KEY_MAME2
set C_MAME=off
GOTO JP-MENU
:JP-KEY_MAME3
set C_MAME=on
GOTO JP-MENU

REM Enable/Disable MESS
:JP-KEY_MESS1
if [%C_MESS%] EQU [on] goto JP-KEY_MESS2
if [%C_MESS%] EQU [off] goto JP-KEY_MESS3
:JP-KEY_MESS2
set C_MESS=off
GOTO JP-MENU
:JP-KEY_MESS3
set C_MESS=on
GOTO JP-MENU

REM Enable/Disable MAMEARCADE
:JP-KEY_MAMEARCADE1
if [%C_MAMEARCADE%] EQU [on] goto JP-KEY_MAMEARCADE2
if [%C_MAMEARCADE%] EQU [off] goto JP-KEY_MAMEARCADE3
:JP-KEY_MAMEARCADE2
set C_MAMEARCADE=off
GOTO JP-MENU
:JP-KEY_MAMEARCADE3
set C_MAMEARCADE=on
GOTO JP-MENU

REM Enable/Disable ARCADE
:JP-KEY_ARCADE1
if [%C_ARCADE%] EQU [on] goto JP-KEY_ARCADE2
if [%C_ARCADE%] EQU [off] goto JP-KEY_ARCADE3
:JP-KEY_ARCADE2
set C_ARCADE=off
GOTO JP-MENU
:JP-KEY_ARCADE3
set C_ARCADE=on
GOTO JP-MENU

REM Enable/Disable MAMEui
:JP-KEY_MAMEui1
if [%C_MAMEui%] EQU [on] goto JP-KEY_MAMEui2
if [%C_MAMEui%] EQU [off] goto JP-KEY_MAMEui3
:JP-KEY_MAMEui2
set C_MAMEui=off
GOTO JP-MENU
:JP-KEY_MAMEui3
set C_MAMEui=on
GOTO JP-MENU

REM Enable/Disable MESSui
:JP-KEY_MESSui1
if [%C_MESSui%] EQU [on] goto JP-KEY_MESSui2
if [%C_MESSui%] EQU [off] goto JP-KEY_MESSui3
:JP-KEY_MESSui2
set C_MESSui=off
GOTO JP-MENU
:JP-KEY_MESSui3
set C_MESSui=on
GOTO JP-MENU

REM Enable/Disable HBMAME
:JP-KEY_HBMAME1
if [%C_HBMAME%] EQU [on] goto JP-KEY_HBMAME2
if [%C_HBMAME%] EQU [off] goto JP-KEY_HBMAME3
:JP-KEY_HBMAME2
set C_HBMAME=off
GOTO JP-MENU
:JP-KEY_HBMAME3
set C_HBMAME=on
GOTO JP-MENU

REM Check the Clean Mode and set it to off or on
:JP-CleanMode1
if [%cleanmode%] EQU [off] goto JP-CleanMode2
if [%cleanmode%] EQU [on] goto JP-CleanMode3
:JP-CleanMode2
set cleanmode=on
GOTO JP-MENU
:JP-CleanMode3
set cleanmode=off
GOTO JP-MENU

REM Check the Pause Mode and set it to off or on
:JP-PauseMode1
if [%batchpause%] EQU [off] goto JP-PauseMode2
if [%batchpause%] EQU [on] goto JP-PauseMode3
:JP-PauseMode2
set batchpause=on
GOTO JP-MENU
:JP-PauseMode3
set batchpause=off
GOTO JP-MENU

:JP-Compiling1
if [%C_MAME%] EQU [off] goto JP-Compiling2
REM Compiling MAME
cls
REM Check if source is installed or not
IF EXIST %~dp0\%MAME_VERSION%\ GOTO JP-check1
ECHO    ---------------------------------------
ECHO      downloading MAME Source
ECHO    ---------------------------------------
ECHO.
REM Copy the source from MAMEDev using the git command
git clone -b %MAME_VERSION% --depth 1 https://github.com/mamedev/mame.git %MAME_VERSION%
:JP-check1
REM check if folder does exists -> if yes delete it with content
IF EXIST %~dp0\_MAME\%MAME_VERSION% rmdir /Q /S %~dp0\_MAME\%MAME_VERSION%
ECHO    ------------------------------------------
ECHO      creating folder  %~dp0\_MAME\%MAME_VERSION%\
ECHO    ------------------------------------------
ECHO.
mkdir %~dp0\_MAME\%MAME_VERSION%\
ECHO    ------------------------------------------
ECHO      Compiling now MAME %MAME_VERSION%
ECHO    ------------------------------------------
ECHO.
cd %~dp0\%MAME_VERSION%
REM first do a cleanup and then compiling with that options
if [%cleanmode%] EQU [on] make.exe clean
REM Compiling MAME
make.exe -%Compilecpu% TOOLS=1 NOWERROR=1 STRIP_SYMBOLS=1 PTR64=1
cd %~dp0\
REM Move all executables from the source folder to this new subfolder
ECHO    ---------------------------------------------
ECHO      moving created files to %~dp0\_MAME\%MAME_VERSION%
ECHO    ---------------------------------------------
ECHO.
move /Y "%~dp0\%MAME_VERSION%\*.exe" "%~dp0\_MAME\%MAME_VERSION%\"
REM copy addon folder/files when enabled
ECHO    ------------------------------------------
ECHO      copying now addon folder structure 
ECHO    ------------------------------------------
ECHO.
xcopy /E "%~dp0\%MAME_VERSION%\artwork" "%~dp0\_MAME\%MAME_VERSION%\artwork\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\bgfx" "%~dp0\_MAME\%MAME_VERSION%\bgfx\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\ctrlr" "%~dp0\_MAME\%MAME_VERSION%\ctrlr\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\docs" "%~dp0\_MAME\%MAME_VERSION%\docs\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\hash" "%~dp0\_MAME\%MAME_VERSION%\hash\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\hlsl" "%~dp0\_MAME\%MAME_VERSION%\hlsl\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\ini" "%~dp0\_MAME\%MAME_VERSION%\ini\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\language" "%~dp0\_MAME\%MAME_VERSION%\language\" >NUL
mkdir "%~dp0\_MAME\%MAME_VERSION%\nl_examples\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\src\lib\netlist\examples\*.*" "%~dp0\_MAME\%MAME_VERSION%\nl_examples\*.*" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\plugins" "%~dp0\_MAME\%MAME_VERSION%\plugins\" >NUL
mkdir "%~dp0\_MAME\%MAME_VERSION%\roms" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\samples" "%~dp0\_MAME\%MAME_VERSION%\samples\" >NUL
if [%batchpause%] EQU [on] pause

:JP-Compiling2
if [%C_MESS%] EQU [off] goto JP-Compiling3
REM Compiling MESS
cls
REM Check if source is installed or not
IF EXIST %~dp0\%MAME_VERSION%\ GOTO JP-check2
ECHO    ---------------------------------------
ECHO      downloading MAME Source
ECHO    ---------------------------------------
ECHO.
REM Copy the source from MAMEDev using the git command
git clone -b %MAME_VERSION% --depth 1 https://github.com/mamedev/mame.git %MAME_VERSION%
:JP-check2
REM check if folder does exists -> if yes delete it with content
IF EXIST %~dp0\_MESS\%MAME_VERSION% rmdir /Q /S %~dp0\_MESS\%MAME_VERSION%
ECHO    ------------------------------------------
ECHO      creating folder  %~dp0\_MESS\%MAME_VERSION%\
ECHO    ------------------------------------------
ECHO.
mkdir %~dp0\_MESS\%MAME_VERSION%\
ECHO    ------------------------------------------
ECHO      Compiling now MESS %MAME_VERSION%
ECHO    ------------------------------------------
ECHO.
cd %~dp0\%MAME_VERSION%
REM first do a cleanup and then compiling with that options
if [%cleanmode%] EQU [on] make.exe clean
REM Compiling MESS
make.exe -%Compilecpu% TOOLS=1 SUBTARGET=mess NOWERROR=1 STRIP_SYMBOLS=1 PTR64=1
cd %~dp0\
REM Move all executables from the source folder to this new subfolder
ECHO    ---------------------------------------------
ECHO      moving created files to %~dp0\_MESS\%MAME_VERSION%
ECHO    ---------------------------------------------
ECHO.
move /Y "%~dp0\%MAME_VERSION%\*.exe" "%~dp0\_MESS\%MAME_VERSION%\"
REM copy addon folder/files when enabled
ECHO    ------------------------------------------
ECHO      copying now addon folder structure 
ECHO    ------------------------------------------
ECHO.
xcopy /E "%~dp0\%MAME_VERSION%\artwork" "%~dp0\_MESS\%MAME_VERSION%\artwork\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\bgfx" "%~dp0\_MESS\%MAME_VERSION%\bgfx\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\ctrlr" "%~dp0\_MESS\%MAME_VERSION%\ctrlr\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\docs" "%~dp0\_MESS\%MAME_VERSION%\docs\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\hash" "%~dp0\_MESS\%MAME_VERSION%\hash\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\hlsl" "%~dp0\_MESS\%MAME_VERSION%\hlsl\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\ini" "%~dp0\_MESS\%MAME_VERSION%\ini\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\language" "%~dp0\_MESS\%MAME_VERSION%\language\" >NUL
mkdir "%~dp0\_MESS\%MAME_VERSION%\nl_examples\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\src\lib\netlist\examples\*.*" "%~dp0\_MESS\%MAME_VERSION%\nl_examples\*.*" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\plugins" "%~dp0\_MESS\%MAME_VERSION%\plugins\" >NUL
mkdir "%~dp0\_MESS\%MAME_VERSION%\roms" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\samples" "%~dp0\_MESS\%MAME_VERSION%\samples\" >NUL
if [%batchpause%] EQU [on] pause

:JP-Compiling3
if [%C_MAMEARCADE%] EQU [off] goto JP-Compiling4
REM Compiling MAMEARCADE
cls
REM Check if source is installed or not
IF EXIST %~dp0\%MAME_VERSION%\ GOTO JP-check3
ECHO    ---------------------------------------
ECHO      downloading MAME Source
ECHO    ---------------------------------------
ECHO.
REM Copy the source from MAMEDev using the git command
git clone -b %MAME_VERSION% --depth 1 https://github.com/mamedev/mame.git %MAME_VERSION%
:JP-check3
REM check if folder does exists -> if yes delete it with content
IF EXIST %~dp0\_MAMEARCADE\%MAME_VERSION% rmdir /Q /S %~dp0\_MAMEARCADE\%MAME_VERSION%
ECHO    ------------------------------------------
ECHO      creating folder  %~dp0\_MAMEARCADE\%MAME_VERSION%\
ECHO    ------------------------------------------
ECHO.
mkdir %~dp0\_MAMEARCADE\%MAME_VERSION%\
ECHO    ------------------------------------------
ECHO      Compiling now MAMEARCADE %MAME_VERSION%
ECHO    ------------------------------------------
ECHO.
cd %~dp0\%MAME_VERSION%
REM first do a cleanup and then compiling with that options
if [%cleanmode%] EQU [on] make.exe clean
REM Compiling MAMEARCADE
make.exe -%Compilecpu% TOOLS=1 SUBTARGET=arcade NOWERROR=1 STRIP_SYMBOLS=1 PTR64=1
cd %~dp0\
REM Move all executables from the source folder to this new subfolder
ECHO    ---------------------------------------------
ECHO      moving created files to %~dp0\_MAMEARCADE\%MAME_VERSION%
ECHO    ---------------------------------------------
ECHO.
move /Y "%~dp0\%MAME_VERSION%\*.exe" "%~dp0\_MAMEARCADE\%MAME_VERSION%\"
REM copy addon folder/files when enabled
ECHO    ------------------------------------------
ECHO      copying now addon folder structure 
ECHO    ------------------------------------------
ECHO.
xcopy /E "%~dp0\%MAME_VERSION%\artwork" "%~dp0\_MAMEARCADE\%MAME_VERSION%\artwork\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\bgfx" "%~dp0\_MAMEARCADE\%MAME_VERSION%\bgfx\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\ctrlr" "%~dp0\_MAMEARCADE\%MAME_VERSION%\ctrlr\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\docs" "%~dp0\_MAMEARCADE\%MAME_VERSION%\docs\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\hash" "%~dp0\_MAMEARCADE\%MAME_VERSION%\hash\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\hlsl" "%~dp0\_MAMEARCADE\%MAME_VERSION%\hlsl\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\ini" "%~dp0\_MAMEARCADE\%MAME_VERSION%\ini\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\language" "%~dp0\_MAMEARCADE\%MAME_VERSION%\language\" >NUL
mkdir "%~dp0\_MAMEARCADE\%MAME_VERSION%\nl_examples\" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\src\lib\netlist\examples\*.*" "%~dp0\_MAMEARCADE\%MAME_VERSION%\nl_examples\*.*" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\plugins" "%~dp0\_MAMEARCADE\%MAME_VERSION%\plugins\" >NUL
mkdir "%~dp0\_MAMEARCADE\%MAME_VERSION%\roms" >NUL
xcopy /E "%~dp0\%MAME_VERSION%\samples" "%~dp0\_MAMEARCADE\%MAME_VERSION%\samples\" >NUL
if [%batchpause%] EQU [on] pause

:JP-Compiling4
if [%C_ARCADE%] EQU [off] goto JP-Compiling5
REM Compiling ARCADE
cls
REM Check if source is installed or not
IF EXIST %~dp0\"arcade_"%ARCADE_VERSION%\ GOTO JP-check4
ECHO    ---------------------------------------
ECHO      downloading ARCADE Source
ECHO    ---------------------------------------
ECHO.
REM Copy the source from ARCADE using the git command
git clone -b %ARCADE_VERSION% --depth 1 https://github.com/Robbbert/store1.git "arcade_"%ARCADE_VERSION%
:JP-check4
REM check if folder does exists -> if yes delete it with content
IF EXIST %~dp0\_ARCADE\%ARCADE_VERSION% rmdir /Q /S %~dp0\_ARCADE\%ARCADE_VERSION%
ECHO    ------------------------------------------
ECHO      creating folder  %~dp0\_ARCADE\%ARCADE_VERSION%\
ECHO    ------------------------------------------
ECHO.
mkdir %~dp0\_ARCADE\%ARCADE_VERSION%\
ECHO    ------------------------------------------
ECHO      Compiling now ARCADE %ARCADE_VERSION%
ECHO    ------------------------------------------
ECHO.
cd %~dp0\arcade_%ARCADE_VERSION%
REM first do a cleanup and then compiling with that options
if [%cleanmode%] EQU [on] make.exe clean
REM Compiling ARCADE
make.exe -%Compilecpu% TOOLS=1 SUBTARGET=arcade OSD=winui NOWERROR=1 STRIP_SYMBOLS=1 PTR64=1
cd %~dp0\
REM Move all executables from the source folder to this new subfolder
ECHO    ---------------------------------------------
ECHO      moving created files to %~dp0\_ARCADE\%ARCADE_VERSION%
ECHO    ---------------------------------------------
ECHO.
move /Y "%~dp0\arcade_%ARCADE_VERSION%\*.exe" "%~dp0\_ARCADE\%ARCADE_VERSION%\"
REM copy addon folder/files when enabled
ECHO    ------------------------------------------
ECHO      copying now addon folder structure 
ECHO    ------------------------------------------
ECHO.
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\artwork" "%~dp0\_ARCADE\%ARCADE_VERSION%\artwork\" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\bgfx" "%~dp0\_ARCADE\%ARCADE_VERSION%\bgfx\" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\ctrlr" "%~dp0\_ARCADE\%ARCADE_VERSION%\ctrlr\" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\docs" "%~dp0\_ARCADE\%ARCADE_VERSION%\docs\" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\hash" "%~dp0\_ARCADE\%ARCADE_VERSION%\hash\" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\hlsl" "%~dp0\_ARCADE\%ARCADE_VERSION%\hlsl\" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\ini" "%~dp0\_ARCADE\%ARCADE_VERSION%\ini\" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\language" "%~dp0\_ARCADE\%ARCADE_VERSION%\language\" >NUL
mkdir "%~dp0\_ARCADE\%ARCADE_VERSION%\nl_examples\" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\src\lib\netlist\examples\*.*" "%~dp0\_ARCADE\%ARCADE_VERSION%\nl_examples\*.*" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\plugins" "%~dp0\_ARCADE\%ARCADE_VERSION%\plugins\" >NUL
mkdir "%~dp0\_ARCADE\%ARCADE_VERSION%\roms" >NUL
xcopy /E "%~dp0\arcade_%ARCADE_VERSION%\samples" "%~dp0\_ARCADE\%ARCADE_VERSION%\samples\" >NUL
if [%batchpause%] EQU [on] pause

:JP-Compiling5
if [%C_MAMEui%] EQU [off] goto JP-Compiling6
REM Compiling MAMEui
cls
IF EXIST %~dp0\"mameui_"%MAMEui_VERSION%\ GOTO JP-check5
ECHO    ---------------------------------------
ECHO      downloading MAMEui Source
ECHO    ---------------------------------------
ECHO.
REM Copy the source from MAMEui using the git command
git clone -b %MAMEui_VERSION% --depth 1 https://github.com/Robbbert/mameui.git "mameui_"%MAMEui_VERSION%
:JP-check5
REM check if folder does exists -> if yes delete it with content
IF EXIST %~dp0\_MAMEui\%MAMEui_VERSION% rmdir /Q /S %~dp0\_MAMEui\%MAMEui_VERSION%
ECHO    ------------------------------------------
ECHO      creating folder  %~dp0\_MAMEui\%MAMEui_VERSION%\
ECHO    ------------------------------------------
ECHO.
mkdir %~dp0\_MAMEui\%MAMEui_VERSION%\
ECHO    ------------------------------------------
ECHO      Compiling now MAMEui %MAMEui_VERSION%
ECHO    ------------------------------------------
ECHO.
cd %~dp0\mameui_%MAMEui_VERSION%
REM first do a cleanup and then compiling with that options
if [%cleanmode%] EQU [on] make.exe clean
REM Compiling MAMEui
make.exe -%Compilecpu% TOOLS=1 OSD=messui NOWERROR=1 STRIP_SYMBOLS=1 PTR64=1
cd %~dp0\
REM Move all executables from the source folder to this new subfolder
ECHO    ---------------------------------------------
ECHO      moving created files to %~dp0\_MAMEui\%MAMEui_VERSION%
ECHO    ---------------------------------------------
ECHO.
move /Y "%~dp0\mameui_%MAMEui_VERSION%\*.exe" "%~dp0\_MAMEui\%MAMEui_VERSION%\"
REM copy addon folder/files when enabled
ECHO    ------------------------------------------
ECHO      copying now addon folder structure 
ECHO    ------------------------------------------
ECHO.
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\artwork" "%~dp0\_MAMEui\%MAMEui_VERSION%\artwork\" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\bgfx" "%~dp0\_MAMEui\%MAMEui_VERSION%\bgfx\" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\ctrlr" "%~dp0\_MAMEui\%MAMEui_VERSION%\ctrlr\" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\docs" "%~dp0\_MAMEui\%MAMEui_VERSION%\docs\" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\hash" "%~dp0\_MAMEui\%MAMEui_VERSION%\hash\" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\hlsl" "%~dp0\_MAMEui\%MAMEui_VERSION%\hlsl\" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\ini" "%~dp0\_MAMEui\%MAMEui_VERSION%\ini\" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\language" "%~dp0\_MAMEui\%MAMEui_VERSION%\language\" >NUL
mkdir "%~dp0\_MAMEui\%MAMEui_VERSION%\nl_examples\" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\src\lib\netlist\examples\*.*" "%~dp0\_MAMEui\%MAMEui_VERSION%\nl_examples\*.*" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\plugins" "%~dp0\_MAMEui\%MAMEui_VERSION%\plugins\" >NUL
mkdir "%~dp0\_MAMEui\%MAMEui_VERSION%\roms" >NUL
xcopy /E "%~dp0\mameui_%MAMEui_VERSION%\samples" "%~dp0\_MAMEui\%MAMEui_VERSION%\samples\" >NUL
if [%batchpause%] EQU [on] pause

:JP-Compiling6
if [%C_MESSui%] EQU [off] goto JP-Compiling7
REM Compiling MESSui
cls
IF EXIST %~dp0\"messui_"%MESSui_VERSION%\ GOTO JP-check6
ECHO    ---------------------------------------
ECHO      downloading MESSui Source
ECHO    ---------------------------------------
ECHO.
REM Copy the source from MESSui using the git command
git clone -b %MESSui_VERSION% --depth 1 https://github.com/Robbbert/messui.git "messui_"%MESSui_VERSION%
:JP-check6
REM check if folder does exists -> if yes delete it with content
IF EXIST %~dp0\_MESSui\%MESSui_VERSION% rmdir /Q /S %~dp0\_MESSui\%MESSui_VERSION%
ECHO    ------------------------------------------
ECHO      creating folder  %~dp0\_MESSui\%MESSui_VERSION%\
ECHO    ------------------------------------------
ECHO.
mkdir %~dp0\_MESSui\%MESSui_VERSION%\
ECHO    ------------------------------------------
ECHO      Compiling now MESSui %MESSui_VERSION%
ECHO    ------------------------------------------
ECHO.
cd %~dp0\messui_%MESSui_VERSION%
REM first do a cleanup and then compiling with that options
if [%cleanmode%] EQU [on] make.exe clean
REM Compiling MESSui
make.exe -%Compilecpu% TOOLS=1 SUBTARGET=mess OSD=messui NOWERROR=1 STRIP_SYMBOLS=1 PTR64=1
cd %~dp0\
REM Move all executables from the source folder to this new subfolder
ECHO    ---------------------------------------------
ECHO      moving created files to %~dp0\_MESSui\%MESSui_VERSION%
ECHO    ---------------------------------------------
ECHO.
move /Y "%~dp0\messui_%MESSui_VERSION%\*.exe" "%~dp0\_MESSui\%MESSui_VERSION%\"
REM copy addon folder/files when enabled
ECHO    ------------------------------------------
ECHO      copying now addon folder structure 
ECHO    ------------------------------------------
ECHO.
xcopy /E "%~dp0\messui_%MESSui_VERSION%\artwork" "%~dp0\_MESSui\%MESSui_VERSION%\artwork\" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\bgfx" "%~dp0\_MESSui\%MESSui_VERSION%\bgfx\" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\ctrlr" "%~dp0\_MESSui\%MESSui_VERSION%\ctrlr\" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\docs" "%~dp0\_MESSui\%MESSui_VERSION%\docs\" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\hash" "%~dp0\_MESSui\%MESSui_VERSION%\hash\" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\hlsl" "%~dp0\_MESSui\%MESSui_VERSION%\hlsl\" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\ini" "%~dp0\_MESSui\%MESSui_VERSION%\ini\" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\language" "%~dp0\_MESSui\%MESSui_VERSION%\language\" >NUL
mkdir "%~dp0\_MESSui\%MESSui_VERSION%\nl_examples\" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\src\lib\netlist\examples\*.*" "%~dp0\_MESSui\%MESSui_VERSION%\nl_examples\*.*" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\plugins" "%~dp0\_MESSui\%MESSui_VERSION%\plugins\" >NUL
mkdir "%~dp0\_MESSui\%MESSui_VERSION%\roms" >NUL
xcopy /E "%~dp0\messui_%MESSui_VERSION%\samples" "%~dp0\_MESSui\%MESSui_VERSION%\samples\" >NUL
if [%batchpause%] EQU [on] pause

:JP-Compiling7
if [%C_HBMAME%] EQU [off] goto JP-MENU
REM Compiling HBMAME_VERSION
cls
IF EXIST %~dp0\"hbmame_"%HBMAME_VERSION%\ GOTO JP-check7
ECHO    ---------------------------------------
ECHO      downloading HBMAME Source
ECHO    ---------------------------------------
ECHO.
REM Copy the source from HBMAME using the git command
git clone -b %HBMAME_VERSION% --depth 1 https://github.com/Robbbert/hbmame.git "hbmame_"%HBMAME_VERSION%
:JP-check7
REM check if folder does exists -> if yes delete it with content
IF EXIST %~dp0\_HBMAME\%HBMAME_VERSION% rmdir /Q /S %~dp0\_HBMAME\%HBMAME_VERSION%
ECHO    ------------------------------------------
ECHO      creating folder  %~dp0\_HBMAME\%HBMAME_VERSION%\
ECHO    ------------------------------------------
ECHO.
mkdir %~dp0\_HBMAME\%HBMAME_VERSION%\
ECHO    ------------------------------------------
ECHO      Compiling now HBMAME %HBMAME_VERSION%
ECHO    ------------------------------------------
ECHO.
cd %~dp0\hbmame_%HBMAME_VERSION%
REM first do a cleanup and then compiling with that options
if [%cleanmode%] EQU [on] make.exe clean
REM Compiling HBMAME
make.exe -%Compilecpu% TARGET=hbmame OSD=winui TOOLS=1 NOWERROR=1 STRIP_SYMBOLS=1 PTR64=1
cd %~dp0\
REM Move all executables from the source folder to this new subfolder
ECHO    ---------------------------------------------
ECHO      moving created files to %~dp0\_HBMAME\%HBMAME_VERSION%
ECHO    ---------------------------------------------
ECHO.
move /Y "%~dp0\hbmame_%HBMAME_VERSION%\*.exe" "%~dp0\_HBMAME\%HBMAME_VERSION%\"
REM copy addon folder/files when enabled
ECHO    ------------------------------------------
ECHO      copying now addon folder structure 
ECHO    ------------------------------------------
ECHO.
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\artwork" "%~dp0\_HBMAME\%HBMAME_VERSION%\artwork\" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\bgfx" "%~dp0\_HBMAME\%HBMAME_VERSION%\bgfx\" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\ctrlr" "%~dp0\_HBMAME\%HBMAME_VERSION%\ctrlr\" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\docs" "%~dp0\_HBMAME\%HBMAME_VERSION%\docs\" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\hash" "%~dp0\_HBMAME\%HBMAME_VERSION%\hash\" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\hlsl" "%~dp0\_HBMAME\%HBMAME_VERSION%\hlsl\" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\ini" "%~dp0\_HBMAME\%HBMAME_VERSION%\ini\" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\language" "%~dp0\_HBMAME\%HBMAME_VERSION%\language\" >NUL
mkdir "%~dp0\_HBMAME\%HBMAME_VERSION%\nl_examples\" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\src\lib\netlist\examples\*.*" "%~dp0\_HBMAME\%HBMAME_VERSION%\nl_examples\*.*" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\plugins" "%~dp0\_HBMAME\%HBMAME_VERSION%\plugins\" >NUL
mkdir "%~dp0\_HBMAME\%HBMAME_VERSION%\roms" >NUL
xcopy /E "%~dp0\hbmame_%HBMAME_VERSION%\samples" "%~dp0\_HBMAME\%HBMAME_VERSION%\samples\" >NUL
if [%batchpause%] EQU [on] pause
GOTO JP-MENU

:JP-EXIT